@@ -40,6 +40,8 @@ typedef cpuset_t cpu_set_t;
 
 #include "../fastnetmon_packet_parser.h"
 
+#include "../unified_parser.hpp"
+
 // For pooling operations
 #include <poll.h>
 
@@ -62,10 +64,10 @@ uint32_t netmap_sampling_ratio = 1;
 void netmap_thread(struct nm_desc* netmap_descriptor, int netmap_thread);
 void consume_pkt(u_char* buffer, int len, int thread_number);
 
-// Get log4cpp logger from main programm
+// Get log4cpp logger from main program
 extern log4cpp::Category& logger;
 
-// Pass unparsed packets number to main programm
+// Pass unparsed packets number to main program
 extern uint64_t total_unparsed_packets;
 
 // Global configuration map
@@ -98,77 +100,13 @@ int receive_packets(struct netmap_ring* ring, int thread_number) {
     return (rx);
 }
 
-bool parse_raw_packet_to_simple_packet(u_char* buffer, int len, simple_packet& packet) {
-    struct pfring_pkthdr packet_header;
-
-    memset(&packet_header, 0, sizeof(packet_header));
-    packet_header.len = len;
-    packet_header.caplen = len;
-
-    // We do not calculate timestamps because timestamping is very CPU intensive operation:
-    // https://github.com/ntop/PF_RING/issues/9
-    u_int8_t timestamp = 0;
-    u_int8_t add_hash = 0;
-    fastnetmon_parse_pkt((u_char*)buffer, &packet_header, 4, timestamp, add_hash);
-
-    // char print_buffer[512];
-    // fastnetmon_print_parsed_pkt(print_buffer, 512, (u_char*)buffer, &packet_header);
-    // logger.info("%s", print_buffer);
-
-    if (packet_header.extended_hdr.parsed_pkt.ip_version != 4 && packet_header.extended_hdr.parsed_pkt.ip_version != 6) {
-        return false;
-    }
-
-    // We need this for deep packet inspection
-    packet.packet_payload_length = len;
-    packet.packet_payload_pointer = (void*)buffer;
-
-    packet.ip_protocol_version = packet_header.extended_hdr.parsed_pkt.ip_version;
-
-    if (packet.ip_protocol_version == 4) {
-        // IPv4
-
-        /* PF_RING stores data in host byte order but we use network byte order */
-        packet.src_ip = htonl(packet_header.extended_hdr.parsed_pkt.ip_src.v4);
-        packet.dst_ip = htonl(packet_header.extended_hdr.parsed_pkt.ip_dst.v4);
-    } else {
-        // IPv6
-        memcpy(packet.src_ipv6.s6_addr, packet_header.extended_hdr.parsed_pkt.ip_src.v6.s6_addr, 16);
-        memcpy(packet.dst_ipv6.s6_addr, packet_header.extended_hdr.parsed_pkt.ip_dst.v6.s6_addr, 16);
-    }
-
-    packet.source_port = packet_header.extended_hdr.parsed_pkt.l4_src_port;
-    packet.destination_port = packet_header.extended_hdr.parsed_pkt.l4_dst_port;
-
-    if (netmap_read_packet_length_from_ip_header) { 
-        packet.length = packet_header.extended_hdr.parsed_pkt.ip_total_size;
-    } else {
-        packet.length = packet_header.len;
-    }
-
-    packet.protocol = packet_header.extended_hdr.parsed_pkt.l3_proto;
-    packet.ts = packet_header.ts;
-
-    packet.ip_fragmented = packet_header.extended_hdr.parsed_pkt.ip_fragmented;
-    packet.ttl = packet_header.extended_hdr.parsed_pkt.ip_ttl;
-
-    // Copy flags from PF_RING header to our pseudo header
-    if (packet.protocol == IPPROTO_TCP) {
-        packet.flags = packet_header.extended_hdr.parsed_pkt.tcp.flags;
-    } else {
-        packet.flags = 0;
-    }
-
-    return true;
-} 
-
 void consume_pkt(u_char* buffer, int len, int thread_number) {
     // We should fill this structure for passing to FastNetMon
     simple_packet packet;
 
     packet.sample_ratio = netmap_sampling_ratio;
 
-    if (!parse_raw_packet_to_simple_packet(buffer, len, packet)) {
+    if (!parse_raw_packet_to_simple_packet(buffer, len, packet, netmap_read_packet_length_from_ip_header)) {
         total_unparsed_packets++;
 
         return;
@@ -210,7 +148,6 @@ void receiver(std::string interface_for_listening) {
 
     if (netmap_descriptor == NULL) {
         logger.error("Can't open netmap device %s", interface.c_str());
-        exit(1);
         return;
     }
 
@@ -259,7 +196,7 @@ void receiver(std::string interface_for_listening) {
 
         if (new_nmd == NULL) {
             logger.error("Can't open netmap descriptor for netmap per hardware queue thread");
-            exit(1);
+            return;
         }
 
         logger.info("My first ring is %d and last ring id is %d I'm thread %d",
@@ -277,7 +214,7 @@ void receiver(std::string interface_for_listening) {
 
 // Well, we have thread attributes from Boost 1.50
 
-#if defined(BOOST_THREAD_PLATFORM_PTHREAD) && BOOST_VERSION / 100 % 1000 >= 50 && !defined(__APPLE__)
+#if defined(BOOST_THREAD_PLATFORM_PTHREAD) && BOOST_VERSION / 100 % 1000 >= 50 && !defined(__APPLE__) && defined(__GLIBC__)
         /* Bind to certain core */
         boost::thread::attributes thread_attrs;
 
